@@ -1,10 +1,9 @@
 # -*- mode: cperl; coding: latin-2 -*-
 
 #
-# $Id: Kwalify.pm,v 1.24 2008/10/05 18:16:02 eserte Exp $
 # Author: Slaven Rezic
 #
-# Copyright (C) 2006,2007,2008 Slaven Rezic. All rights reserved.
+# Copyright (C) 2006,2007,2008,2009 Slaven Rezic. All rights reserved.
 # This package is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 #
@@ -20,8 +19,7 @@ use base qw(Exporter);
 use vars qw(@EXPORT_OK $VERSION);
 @EXPORT_OK = qw(validate);
 
-$VERSION = '1.20';
-# sprintf("%d.%02d", q$Revision: 1.24 $ =~ /(\d+)\.(\d+)/);
+$VERSION = '1.21';
 
 BEGIN {
     if ($] < 5.006) {
@@ -355,12 +353,13 @@ sub validate_map {
 	}
 	my $unique = _get_boolean($subschema->{unique});
 	if ($unique) {
-	    if (defined $unique_mapping_val->{$key}->{val} && $unique_mapping_val->{$key}->{val} eq $data->{$key}) {
-		$self->_error("'$data->{$key}' is already used at '$unique_mapping_val->{$key}->{path}'");
+	    if (defined $unique_mapping_val->{$data->{$key}}->{val} 
+		&& $unique_mapping_val->{$data->{$key}}->{val} eq $data->{$key}) {
+		$self->_error("'$data->{$key}' is already used at '$unique_mapping_val->{$data->{$key}}->{path}'");
 	    } else {
-		$unique_mapping_val->{$key} = { val  => $data->{$key},
-						path => $subpath,
-					      };
+		$unique_mapping_val->{$data->{$key}} = { val  => $data->{$key},
+							 path => $subpath,
+						       };
 	    }
 	}
 
@@ -549,7 +548,7 @@ Slaven Rezi, E<lt>srezic@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2006,2007,2008 by Slaven Rezi
+Copyright (C) 2006,2007,2008,2009 by Slaven Rezi
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.8 or,
